%global _description\
Schemas for messages sent by Copr project, as described on \
fedora-messaging documentation page \
https://fedora-messaging.readthedocs.io/en/latest/messages.html#schema \
\
Package also provides several convenience methods for working with \
copr messages.

Name:       copr-messaging
Version:    0.11
Release:    1.20240519213712091872.main.31.g2a0557de9%{?dist}
Summary:    Abstraction for Copr messaging listeners/publishers

License:    GPL-2.0-or-later
URL:        https://github.com/fedora-copr/copr

# Source is created by:
# git clone %%url && cd copr
# tito build --tgz --tag %%name-%%version-%%release
Source0:    copr-messaging-git-0.aee11bd.tar.gz

BuildArch:  noarch

Requires:      wget


BuildRequires: asciidoc
BuildRequires: libxslt
BuildRequires: util-linux

BuildRequires: python3-copr-common
BuildRequires: python3-devel
BuildRequires: python3-fedora-messaging
BuildRequires: python3-pytest
BuildRequires: python3-setuptools
BuildRequires: python3-sphinx

%description %_description


%package -n python3-%name
Summary: %summary
Provides: %name = %version
%{?python_provide:%python_provide python3-%{name}}

Requires: python3-copr-common
Requires: python3-fedora-messaging

%description -n python3-%name %_description

%package -n python3-%name-doc
Summary: Code documentation for copr messaging

%description -n python3-%name-doc %_description

This package contains documentation for copr-messaging.


%prep
%setup -q -n copr-messaging-git-0.aee11bd


%build
%py3_build
PYTHONPATH=${PWD} sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}


%install
%py3_install


%check
./run_tests.sh -vv


%files -n python3-%name
%license LICENSE
%doc README.md
%python3_sitelib/copr_messaging
%python3_sitelib/copr_messaging*egg-info

%files -n python3-%name-doc
%license LICENSE
%doc html


%changelog
* Sun May 19 2024 Packit <hello@packit.dev> - 0.11-1.20240519213712091872.main.31.g2a0557de9
- frontend: Add per package timeout option (Robert-André Mauchin)
- alembic: fix a migration syntax warning (Pavel Raiskup)
- frontend: eol-emails deterministic (Pavel Raiskup)
- doc: add Copr CLI - Package Management video (Jakub Kadlcik)
- docker: Update Dockerfiles for backend_httpd and database (Robert-André Mauchin)
- python: discourage from deleting objects while paginating over them (Jakub Kadlcik)
- doc: reST link typo (Pavel Raiskup)
- doc: document that log-out from Ipsilon might help (Pavel Raiskup)
- frontend: list temporary project after normal projects (Jakub Kadlcik)
- frontend: don't index unlisted and temporary projects (Jakub Kadlcik)
- frontend: speedup the update-indexes command (Jakub Kadlcik)
- doc: mention cleaning after creating new images (Miroslav Suchý)
- doc: update the outage documentation, add e-mail template (Pavel Raiskup)
- doc: fixes for the latest release cycle (Pavel Raiskup)
- frontend: make EOL chroot emails shorter (Jakub Kadlcik)
- frontend: add tests for branching custom directory (Jakub Kadlcik)
- backend: multiple attempts to create repository before giving up (Jakub Kadlcik)
- frontend, backend: run rawhide-to-release for all CoprDirs (Jakub Kadlcik)
- doc: add Copr CLI - Fetching Build Results video (Jakub Kadlcik)
- beaker-tests-sanity: add -s so we can parse the build ID (Jakub Kadlcik)
- frontend: delete compatibility code between flask and flask-restx (Jiri Kyjovsky)
- frontend: migrate builds to flask-restx (Jiri Kyjovsky)
- python: suggest pagination only when a GET request timeouts (Jakub Kadlcik)
- cli: remove dependency on simplejson (Jakub Kadlcik)
- beaker-tests-sanity: add tests for build batches (Jakub Kadlcik)
- build(deps): bump actions/add-to-project from 1.0.0 to 1.0.1 (dependabot[bot])
- frontend: fix bug in reporting failed SRPMs to log-detective (Jiri Kyjovsky)
- beaker-tests-sanity: migrate test repositories from Pagure to GitHub (Jakub Kadlcik)
- frontend: commit after every 10 deleted projects instead of 100 (Jakub Kadlcik)
- doc: add release notes 2024-04-12 (Jakub Kadlcik)
- frontend: don't pass raw SQL as string but rather SQLAlchemy text (Jakub Kadlcik)
- Automatic commit of package [copr-frontend] release [1.205-1]. (Jakub Kadlcik)
- frontend: fix url_for for restx (Jiri Kyjovsky)
- backend, rpmbuild: remove static methods from tests (Jakub Kadlcik)
- common: fix chroot_to_branch default (Pavel Raiskup)
- frontend: update download stats footnote (Jakub Kadlcik)
- doc: document DistGit cleanup (Pavel Raiskup)
- dist-git: don't expect remove_unused_sources is in /usr/bin (Pavel Raiskup)
- dist-git: drop unused lookaside-cache cleanup scripts (Pavel Raiskup)
- frontend: migrate more enpoints to flask-restx (Jiri Kyjovsky)
- frontend: speedup the removal of temporary projects (Jakub Kadlcik)
- build(deps): bump actions/add-to-project from 0.6.1 to 1.0.0 (dependabot[bot])
- frontend: add link to the Outdated chroots removal policy (Jakub Kadlcik)
- doc: link Using Copr CLI - Custom build method video (Jakub Kadlcik)
- build(deps): bump actions/add-to-project from 0.6.0 to 0.6.1 (dependabot[bot])
- releng: koji-infratag-* scripts unified and support epel (Pavel Raiskup)
- doc: mention the SSH access to Copr builders blog post (Jakub Kadlcik)
- Automatic commit of package [copr-rpmbuild] release [0.72-1]. (Pavel Raiskup)
- Automatic commit of package [copr-backend] release [1.176-1]. (Pavel Raiskup)
- Automatic commit of package [python-copr-common] release [0.23-1]. (Pavel Raiskup)
- common: make get_redis_connection to accept dict(opts) (Pavel Raiskup)
- rpmbuild: don't clean after builds with user ssh access (Jakub Kadlcik)
- backend: print user SSH instructions before the build starts (Jakub Kadlcik)
- frontend: run the check for anitya updates script under app context (Jakub Kadlcik)
- frontend: pick the outdated chroot more deterministically (Jakub Kadlcik)
- frontend: remove unused import (Jakub Kadlcik)
- frontend: explicitly add new objects to the transaction (Jakub Kadlcik)
- frontend: use ORM attributes in queries (Jakub Kadlcik)
- frontend: specify local_attr and remote_attr (Jakub Kadlcik)
- frontend: use context manager for SQLAlchemy execute (Jakub Kadlcik)
- doc: release-notes/2024-03-07 link typo (Pavel Raiskup)
- doc: release-notes/2024-03-07 (Pavel Raiskup)
- build(deps): bump actions/add-to-project from 0.5.0 to 0.6.0 (dependabot[bot])
- Automatic commit of package [copr-frontend] release [1.204-1]. (Pavel Raiskup)
- frontend: opt-in the log-detective.com button (Pavel Raiskup)
- Automatic commit of package [copr-backend] release [1.175-1]. (Pavel Raiskup)
- backend: use correct (renamed) _discard_running_worker (Pavel Raiskup)
- Automatic commit of package [copr-rpmbuild] release [0.71-1]. (Pavel Raiskup)
- rpmbuild: drop copr-builder help message (Jiri Kyjovsky)
- releng: don't release to EOL F37 (Pavel Raiskup)
- Automatic commit of package [copr-frontend] release [1.203-1]. (Pavel Raiskup)
- Automatic commit of package [copr-backend] release [1.174-1]. (Pavel Raiskup)
- Automatic commit of package [copr-dist-git] release [0.69-1]. (Pavel Raiskup)
- Automatic commit of package [copr-keygen] release [1.92-1]. (Pavel Raiskup)

* Fri Mar 01 2024 Pavel Raiskup <praiskup@redhat.com> 0.11-1
- handle namespaced usernames
- set the agent_name and usernames properties

* Mon May 22 2023 Jakub Kadlcik <frostyx@email.cz> 0.10-1
- Derive all message classes from _CoprMessage

* Wed Mar 22 2023 Jiri Kyjovsky <j1.kyjovsky@gmail.com> 0.9-1
- Add app_name property to _CoprMessage base class
* Tue Jan 24 2023 Jakub Kadlcik <frostyx@email.cz> 0.8-1
- Use SPDX license

* Sat Nov 26 2022 Jakub Kadlcik <frostyx@email.cz> 0.7-1
- move to GitHub home page
- sync tooling with other sub-projects

* Tue Jun 21 2022 Jakub Kadlcik <frostyx@email.cz> 0.6-1
- Adapt to the changed stomppy API

* Mon Nov 09 2020 Jakub Kadlcik <frostyx@email.cz> 0.5-1
- explicitely requires python3-setuptools
- all: run pytest with -vv in package build
- pylint: sync all the pylintrc files
- pylint: run pylint in all run*tests.sh files

* Thu Oct 03 2019 Pavel Raiskup <praiskup@redhat.com> 0.4-1
- rename 'stomp_consumer' module to 'stomp'
- fix macros in comments

* Thu Jul 25 2019 Pavel Raiskup <praiskup@redhat.com> 0.3-1
- mention how to create Source0 tarball

* Wed Jul 24 2019 Pavel Raiskup <praiskup@redhat.com> 0.2-1
- apply review fixes (by Silvie)

* Wed Jul 17 2019 Pavel Raiskup <praiskup@redhat.com> 0.1-1
- copr_messaging: new package for working with copr messages
